Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6569)

Unified Diff: chrome/browser/ui/webui/settings/people_handler.h

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/settings/people_handler.h
diff --git a/chrome/browser/ui/webui/settings/people_handler.h b/chrome/browser/ui/webui/settings/people_handler.h
index bf19c5ceb81ac133a355def36871cd401f626e85..da243e09e8029a1f93e09418f22bf9bf6e967f32 100644
--- a/chrome/browser/ui/webui/settings/people_handler.h
+++ b/chrome/browser/ui/webui/settings/people_handler.h
@@ -71,10 +71,10 @@ class PeopleHandler : public SettingsPageUIHandler,
private:
friend class PeopleHandlerTest;
FRIEND_TEST_ALL_PREFIXES(PeopleHandlerTest,
- DisplayConfigureWithBackendDisabledAndCancel);
+ DisplayConfigureWithEngineDisabledAndCancel);
FRIEND_TEST_ALL_PREFIXES(
PeopleHandlerTest,
- DisplayConfigureWithBackendDisabledAndSyncStartupCompleted);
+ DisplayConfigureWithEngineDisabledAndSyncStartupCompleted);
FRIEND_TEST_ALL_PREFIXES(PeopleHandlerTest, HandleSetupUIWhenSyncDisabled);
FRIEND_TEST_ALL_PREFIXES(PeopleHandlerTest, SelectCustomEncryption);
FRIEND_TEST_ALL_PREFIXES(PeopleHandlerTest, ShowSyncSetupWhenNotSignedIn);
@@ -160,7 +160,7 @@ class PeopleHandler : public SettingsPageUIHandler,
// is running in the background.
void DisplaySpinner();
// Displays an error dialog which shows timeout of starting the sync backend.
void DisplayTimeout();
// Closes the associated sync settings page.
@@ -178,7 +178,7 @@ class PeopleHandler : public SettingsPageUIHandler,
// Weak pointer.
Profile* profile_;
// Helper object used to wait for the sync backend to startup.
std::unique_ptr<SyncStartupTracker> sync_startup_tracker_;
// Prevents Sync from running until configuration is complete.
@@ -189,9 +189,9 @@ class PeopleHandler : public SettingsPageUIHandler,
// histograms in the case that the user cancels out.
bool configuring_sync_;
// The OneShotTimer object used to timeout of starting the sync backend
// service.
- std::unique_ptr<base::OneShotTimer> backend_start_timer_;
+ std::unique_ptr<base::OneShotTimer> engine_start_timer_;
// Used to listen for pref changes to allow or disallow signin.
PrefChangeRegistrar profile_pref_registrar_;
« no previous file with comments | « chrome/browser/ui/webui/options/sync_setup_handler_unittest.cc ('k') | chrome/browser/ui/webui/settings/people_handler.cc » ('j') | no next file with comments »
@@ -160,7 +160,7 @@ class PeopleHandler : public SettingsPageUIHandler,
// is running in the background.
void DisplaySpinner();
- // Displays an error dialog which shows timeout of starting the sync backend.
+ // Displays an error dialog which shows timeout of starting the sync engine.
void DisplayTimeout();
// Closes the associated sync settings page.
@@ -178,7 +178,7 @@ class PeopleHandler : public SettingsPageUIHandler,
// Weak pointer.
Profile* profile_;
- // Helper object used to wait for the sync backend to startup.
+ // Helper object used to wait for the sync engine to startup.
std::unique_ptr<SyncStartupTracker> sync_startup_tracker_;
// Prevents Sync from running until configuration is complete.
@@ -189,9 +189,9 @@ class PeopleHandler : public SettingsPageUIHandler,
// histograms in the case that the user cancels out.
bool configuring_sync_;
- // The OneShotTimer object used to timeout of starting the sync backend
+ // The OneShotTimer object used to timeout of starting the sync engine
// service.

Powered by Google App Engine
This is Rietveld 408576698